##  Permission Types
The following permission types are available for presentations:
  * Can edit: All workspace users can view and edit the presentation.
  * Can view: All workspace users can view the presentation, but only specific users who are granted editing permissions can edit it.
  * No access: Only you can view and edit the presentation. Only specific users who are granted viewing or editing permissions can view or edit the presentation.
